#############
Reference/API
#############

=======
Fitting
=======

.. automodule:: mcfine.fitting
    :members:

***************
HyperfineFitter
***************

.. autoclass:: mcfine.fitting.HyperfineFitter
    :members:

========
Plotting
========

.. automodule:: mcfine.plotting
    :members:

****************
HyperfinePlotter
****************

.. autoclass:: mcfine.plotting.HyperfinePlotter
    :members:

=========
Utilities
=========

.. automodule:: mcfine.utils
    :members:
